==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm5/lib/Stacked100AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedAreaSeries } from "./StackedAreaSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedAreaSeriesView } from "./StackedAreaSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100AreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeries, _super);
    function Stacked100AreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100AreaSeries.$;
        return _this;
    }
    Stacked100AreaSeries.prototype.get_tx = function () {
        return true;
    };
    Stacked100AreaSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.mn(false);
    };
    Stacked100AreaSeries.prototype.by = function () {
        return new Stacked100AreaSeriesView(this);
    };
    Stacked100AreaSeries.prototype.l4 = function (a) {
        _super.prototype.l4.call(this, a);
        this.uv = a;
    };
    Stacked100AreaSeries.prototype.ud = function () {
        _super.prototype.ud.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100AreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.ss;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100AreaSeries.$t = markType(Stacked100AreaSeries, 'Stacked100AreaSeries', StackedAreaSeries.$, [IStacked100Series_$type]);
    return Stacked100AreaSeries;
}(StackedAreaSeries));
export { Stacked100AreaSeries };
/**
 * @hidden
 */
var Stacked100AreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeriesView, _super);
    function Stacked100AreaSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100AreaSeriesView.prototype.as = function () {
        _super.prototype.as.call(this);
        if (!this.q) {
            this.c0.ql = Defaults.e;
        }
    };
    Stacked100AreaSeriesView.$t = markType(Stacked100AreaSeriesView, 'Stacked100AreaSeriesView', StackedAreaSeriesView.$);
    return Stacked100AreaSeriesView;
}(StackedAreaSeriesView));
export { Stacked100AreaSeriesView };

==> igniteui-angular-charts-17.2.0-beta.0.tgz: package/esm5/lib/Stacked100AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StackedAreaSeries } from "./StackedAreaSeries";
import { IStacked100Series_$type } from "./IStacked100Series";
import { markType } from "igniteui-angular-core";
import { Stacked100DataPreparer } from "./Stacked100DataPreparer";
import { StackedAreaSeriesView } from "./StackedAreaSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var Stacked100AreaSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeries, _super);
    function Stacked100AreaSeries() {
        var _this = _super.call(this) || this;
        _this.ab = Stacked100AreaSeries.$;
        return _this;
    }
    Stacked100AreaSeries.prototype.get_xn = function () {
        return true;
    };
    Stacked100AreaSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pp(false);
    };
    Stacked100AreaSeries.prototype.cg = function () {
        return new Stacked100AreaSeriesView(this);
    };
    Stacked100AreaSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.yl = a;
    };
    Stacked100AreaSeries.prototype.x3 = function () {
        _super.prototype.x3.call(this);
        Stacked100DataPreparer.a(this);
    };
    Object.defineProperty(Stacked100AreaSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wi;
        },
        enumerable: false,
        configurable: true
    });
    Stacked100AreaSeries.$t = markType(Stacked100AreaSeries, 'Stacked100AreaSeries', StackedAreaSeries.$, [IStacked100Series_$type]);
    return Stacked100AreaSeries;
}(StackedAreaSeries));
export { Stacked100AreaSeries };
/**
 * @hidden
 */
var Stacked100AreaSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Stacked100AreaSeriesView, _super);
    function Stacked100AreaSeriesView(a) {
        return _super.call(this, a) || this;
    }
    Stacked100AreaSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.ua = Defaults.e;
        }
    };
    Stacked100AreaSeriesView.$t = markType(Stacked100AreaSeriesView, 'Stacked100AreaSeriesView', StackedAreaSeriesView.$);
    return Stacked100AreaSeriesView;
}(StackedAreaSeriesView));
export { Stacked100AreaSeriesView };
